@@ -179,9 +179,13 @@ ifdhandler_run(ifd_reader_t *reader)
 	}
 
 	sock = ct_socket_new(0);
+#if defined (sunray)
 	snprintf(socket_name, sizeof(socket_name),
-			OPENCT_SOCKET_PATH "/%u",
-			opt_reader);
+			"%s/openct/%u", getenv("UTDEVROOT"), opt_reader);
+#else
+	snprintf(socket_name, sizeof(socket_name),
+			"%s/%u", OPENCT_SOCKET_PATH, opt_reader);
+#endif
 	if (ct_socket_listen(sock, socket_name, 0666) < 0) {
 		ct_error("Failed to create server socket");
 		exit(1);
@@ -409,13 +413,14 @@ version(void)
 void
 usage(int exval)
 {
-	fprintf(stderr,
+	fprintf(exval ? stderr : stdout,
 "usage: ifdhandler [-Hds] [-r reader] driver [device]\n"
 "  -r   specify index of reader\n"
 "  -F   stay in foreground\n"
 "  -H   hotplug device, monitor for detach\n"
 "  -s   send error and debug messages to syslog\n"
 "  -d   enable debugging; repeat to increase verbosity\n"
+"  -i   display list of available drivers and protocols\n"
 "  -h   display this message\n"
 "  -v   display version and exit\n"
 );
