@@ -8,7 +8,7 @@
  */
 
 #include "internal.h"
-#ifdef __linux__
+#if defined (__linux__) && !defined (sunray)
 #include <sys/types.h>
 #include <linux/major.h>
 #include <linux/compiler.h>
@@ -22,6 +22,7 @@
 #include <signal.h>
 #include <stdlib.h>
 #include <unistd.h>
+#include <fcntl.h>
 #include <errno.h>
 #ifdef HAVE_LIBUSB
 #include <usb.h>
@@ -301,6 +302,12 @@ ifd_sysdep_usb_end_capture(ifd_device_t *dev, ifd_usb_capture_t *cap)
 	return rc;
 }
 
+int
+ifd_sysdep_usb_open(char *device, int flags)
+{
+    return open(device, O_EXCL | O_RDWR);
+}
+
 /*
  * Scan all usb devices to see if there is one we support
  */
